# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class NamespaceCreateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'namespace_code': 'str',
        'charge_code': 'str'
    }

    attribute_map = {
        'namespace_code': 'namespaceCode',
        'charge_code': 'chargeCode'
    }

    def __init__(self, namespace_code=None, charge_code=None):  # noqa: E501
        """NamespaceCreateRequest - a model defined in OpenAPI"""  # noqa: E501

        self._namespace_code = None
        self._charge_code = None
        self.discriminator = None

        self.namespace_code = namespace_code
        if charge_code is not None:
            self.charge_code = charge_code

    @property
    def namespace_code(self):
        """Gets the namespace_code of this NamespaceCreateRequest.  # noqa: E501

        The Namespace code  # noqa: E501

        :return: The namespace_code of this NamespaceCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._namespace_code

    @namespace_code.setter
    def namespace_code(self, namespace_code):
        """Sets the namespace_code of this NamespaceCreateRequest.

        The Namespace code  # noqa: E501

        :param namespace_code: The namespace_code of this NamespaceCreateRequest.  # noqa: E501
        :type: str
        """
        if namespace_code is None:
            raise ValueError("Invalid value for `namespace_code`, must not be `None`")  # noqa: E501

        self._namespace_code = namespace_code

    @property
    def charge_code(self):
        """Gets the charge_code of this NamespaceCreateRequest.  # noqa: E501

        An optional charge code that is associated with the Namespace  # noqa: E501

        :return: The charge_code of this NamespaceCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._charge_code

    @charge_code.setter
    def charge_code(self, charge_code):
        """Sets the charge_code of this NamespaceCreateRequest.

        An optional charge code that is associated with the Namespace  # noqa: E501

        :param charge_code: The charge_code of this NamespaceCreateRequest.  # noqa: E501
        :type: str
        """

        self._charge_code = charge_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NamespaceCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class StorageUnitNotificationRegistrationUpdateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'storage_unit_event_type': 'str',
        'storage_unit_notification_filter': 'StorageUnitNotificationFilter',
        'job_actions': 'list[JobAction]',
        'notification_registration_status': 'str'
    }

    attribute_map = {
        'storage_unit_event_type': 'storageUnitEventType',
        'storage_unit_notification_filter': 'storageUnitNotificationFilter',
        'job_actions': 'jobActions',
        'notification_registration_status': 'notificationRegistrationStatus'
    }

    def __init__(self, storage_unit_event_type=None, storage_unit_notification_filter=None, job_actions=None, notification_registration_status=None):  # noqa: E501
        """StorageUnitNotificationRegistrationUpdateRequest - a model defined in OpenAPI"""  # noqa: E501

        self._storage_unit_event_type = None
        self._storage_unit_notification_filter = None
        self._job_actions = None
        self._notification_registration_status = None
        self.discriminator = None

        self.storage_unit_event_type = storage_unit_event_type
        self.storage_unit_notification_filter = storage_unit_notification_filter
        if job_actions is not None:
            self.job_actions = job_actions
        self.notification_registration_status = notification_registration_status

    @property
    def storage_unit_event_type(self):
        """Gets the storage_unit_event_type of this StorageUnitNotificationRegistrationUpdateRequest.  # noqa: E501

        The type of storage unit event in which this notification should trigger. Supported event types: STRGE_UNIT_STTS_CHG                  # noqa: E501

        :return: The storage_unit_event_type of this StorageUnitNotificationRegistrationUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._storage_unit_event_type

    @storage_unit_event_type.setter
    def storage_unit_event_type(self, storage_unit_event_type):
        """Sets the storage_unit_event_type of this StorageUnitNotificationRegistrationUpdateRequest.

        The type of storage unit event in which this notification should trigger. Supported event types: STRGE_UNIT_STTS_CHG                  # noqa: E501

        :param storage_unit_event_type: The storage_unit_event_type of this StorageUnitNotificationRegistrationUpdateRequest.  # noqa: E501
        :type: str
        """
        if storage_unit_event_type is None:
            raise ValueError("Invalid value for `storage_unit_event_type`, must not be `None`")  # noqa: E501

        self._storage_unit_event_type = storage_unit_event_type

    @property
    def storage_unit_notification_filter(self):
        """Gets the storage_unit_notification_filter of this StorageUnitNotificationRegistrationUpdateRequest.  # noqa: E501


        :return: The storage_unit_notification_filter of this StorageUnitNotificationRegistrationUpdateRequest.  # noqa: E501
        :rtype: StorageUnitNotificationFilter
        """
        return self._storage_unit_notification_filter

    @storage_unit_notification_filter.setter
    def storage_unit_notification_filter(self, storage_unit_notification_filter):
        """Sets the storage_unit_notification_filter of this StorageUnitNotificationRegistrationUpdateRequest.


        :param storage_unit_notification_filter: The storage_unit_notification_filter of this StorageUnitNotificationRegistrationUpdateRequest.  # noqa: E501
        :type: StorageUnitNotificationFilter
        """
        if storage_unit_notification_filter is None:
            raise ValueError("Invalid value for `storage_unit_notification_filter`, must not be `None`")  # noqa: E501

        self._storage_unit_notification_filter = storage_unit_notification_filter

    @property
    def job_actions(self):
        """Gets the job_actions of this StorageUnitNotificationRegistrationUpdateRequest.  # noqa: E501

        The list of jobs to execute when this notification is triggered  # noqa: E501

        :return: The job_actions of this StorageUnitNotificationRegistrationUpdateRequest.  # noqa: E501
        :rtype: list[JobAction]
        """
        return self._job_actions

    @job_actions.setter
    def job_actions(self, job_actions):
        """Sets the job_actions of this StorageUnitNotificationRegistrationUpdateRequest.

        The list of jobs to execute when this notification is triggered  # noqa: E501

        :param job_actions: The job_actions of this StorageUnitNotificationRegistrationUpdateRequest.  # noqa: E501
        :type: list[JobAction]
        """

        self._job_actions = job_actions

    @property
    def notification_registration_status(self):
        """Gets the notification_registration_status of this StorageUnitNotificationRegistrationUpdateRequest.  # noqa: E501

        The status of the notification registration. One of the following values: ENABLED or DISABLED  # noqa: E501

        :return: The notification_registration_status of this StorageUnitNotificationRegistrationUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._notification_registration_status

    @notification_registration_status.setter
    def notification_registration_status(self, notification_registration_status):
        """Sets the notification_registration_status of this StorageUnitNotificationRegistrationUpdateRequest.

        The status of the notification registration. One of the following values: ENABLED or DISABLED  # noqa: E501

        :param notification_registration_status: The notification_registration_status of this StorageUnitNotificationRegistrationUpdateRequest.  # noqa: E501
        :type: str
        """
        if notification_registration_status is None:
            raise ValueError("Invalid value for `notification_registration_status`, must not be `None`")  # noqa: E501

        self._notification_registration_status = notification_registration_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StorageUnitNotificationRegistrationUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class EmrClusterDefinitionInstanceFleet(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'instance_fleet_type': 'str',
        'target_on_demand_capacity': 'int',
        'target_spot_capacity': 'int',
        'instance_type_configs': 'list[EmrClusterDefinitionInstanceTypeConfig]',
        'launch_specifications': 'EmrClusterDefinitionLaunchSpecifications'
    }

    attribute_map = {
        'name': 'name',
        'instance_fleet_type': 'instanceFleetType',
        'target_on_demand_capacity': 'targetOnDemandCapacity',
        'target_spot_capacity': 'targetSpotCapacity',
        'instance_type_configs': 'instanceTypeConfigs',
        'launch_specifications': 'launchSpecifications'
    }

    def __init__(self, name=None, instance_fleet_type=None, target_on_demand_capacity=None, target_spot_capacity=None, instance_type_configs=None, launch_specifications=None):  # noqa: E501
        """EmrClusterDefinitionInstanceFleet - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._instance_fleet_type = None
        self._target_on_demand_capacity = None
        self._target_spot_capacity = None
        self._instance_type_configs = None
        self._launch_specifications = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if instance_fleet_type is not None:
            self.instance_fleet_type = instance_fleet_type
        if target_on_demand_capacity is not None:
            self.target_on_demand_capacity = target_on_demand_capacity
        if target_spot_capacity is not None:
            self.target_spot_capacity = target_spot_capacity
        if instance_type_configs is not None:
            self.instance_type_configs = instance_type_configs
        if launch_specifications is not None:
            self.launch_specifications = launch_specifications

    @property
    def name(self):
        """Gets the name of this EmrClusterDefinitionInstanceFleet.  # noqa: E501

        The friendly name of the instance fleet  # noqa: E501

        :return: The name of this EmrClusterDefinitionInstanceFleet.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this EmrClusterDefinitionInstanceFleet.

        The friendly name of the instance fleet  # noqa: E501

        :param name: The name of this EmrClusterDefinitionInstanceFleet.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def instance_fleet_type(self):
        """Gets the instance_fleet_type of this EmrClusterDefinitionInstanceFleet.  # noqa: E501

        The node type that the instance fleet hosts. Valid values are MASTER,CORE,and TASK  # noqa: E501

        :return: The instance_fleet_type of this EmrClusterDefinitionInstanceFleet.  # noqa: E501
        :rtype: str
        """
        return self._instance_fleet_type

    @instance_fleet_type.setter
    def instance_fleet_type(self, instance_fleet_type):
        """Sets the instance_fleet_type of this EmrClusterDefinitionInstanceFleet.

        The node type that the instance fleet hosts. Valid values are MASTER,CORE,and TASK  # noqa: E501

        :param instance_fleet_type: The instance_fleet_type of this EmrClusterDefinitionInstanceFleet.  # noqa: E501
        :type: str
        """

        self._instance_fleet_type = instance_fleet_type

    @property
    def target_on_demand_capacity(self):
        """Gets the target_on_demand_capacity of this EmrClusterDefinitionInstanceFleet.  # noqa: E501

        The target capacity of On-Demand units for the instance fleet, which determines how many On-Demand instances to provision. When                   the instance fleet launches, Amazon EMR tries to provision On-Demand instances as specified by InstanceTypeConfig. Each instance configuration                   has a specified WeightedCapacity. When an On-Demand instance is provisioned, the WeightedCapacity units count toward the target capacity.                   Amazon EMR provisions instances until the target capacity is totally fulfilled, even if this results in an overage. For example, if there are                   2 units remaining to fulfill capacity, and Amazon EMR can only provision an instance with a WeightedCapacity of 5 units, the instance is                   provisioned, and the target capacity is exceeded by 3 units.                   NOTE: If not specified or set to 0, only Spot instances are provisioned for the instance fleet using TargetSpotCapacity. At least one of                   TargetSpotCapacity and TargetOnDemandCapacity should be greater than 0. For a master instance fleet, only one of TargetSpotCapacity and                   TargetOnDemandCapacity can be specified, and its value must be 1.                  # noqa: E501

        :return: The target_on_demand_capacity of this EmrClusterDefinitionInstanceFleet.  # noqa: E501
        :rtype: int
        """
        return self._target_on_demand_capacity

    @target_on_demand_capacity.setter
    def target_on_demand_capacity(self, target_on_demand_capacity):
        """Sets the target_on_demand_capacity of this EmrClusterDefinitionInstanceFleet.

        The target capacity of On-Demand units for the instance fleet, which determines how many On-Demand instances to provision. When                   the instance fleet launches, Amazon EMR tries to provision On-Demand instances as specified by InstanceTypeConfig. Each instance configuration                   has a specified WeightedCapacity. When an On-Demand instance is provisioned, the WeightedCapacity units count toward the target capacity.                   Amazon EMR provisions instances until the target capacity is totally fulfilled, even if this results in an overage. For example, if there are                   2 units remaining to fulfill capacity, and Amazon EMR can only provision an instance with a WeightedCapacity of 5 units, the instance is                   provisioned, and the target capacity is exceeded by 3 units.                   NOTE: If not specified or set to 0, only Spot instances are provisioned for the instance fleet using TargetSpotCapacity. At least one of                   TargetSpotCapacity and TargetOnDemandCapacity should be greater than 0. For a master instance fleet, only one of TargetSpotCapacity and                   TargetOnDemandCapacity can be specified, and its value must be 1.                  # noqa: E501

        :param target_on_demand_capacity: The target_on_demand_capacity of this EmrClusterDefinitionInstanceFleet.  # noqa: E501
        :type: int
        """

        self._target_on_demand_capacity = target_on_demand_capacity

    @property
    def target_spot_capacity(self):
        """Gets the target_spot_capacity of this EmrClusterDefinitionInstanceFleet.  # noqa: E501

        The target capacity of Spot units for the instance fleet, which determines how many Spot instances to provision. When the                   instance fleet launches, Amazon EMR tries to provision Spot instances as specified by InstanceTypeConfig. Each instance configuration has a                   specified WeightedCapacity. When a Spot instance is provisioned, the WeightedCapacity units count toward the target capacity. Amazon EMR                   provisions instances until the target capacity is totally fulfilled, even if this results in an overage. For example, if there are 2 units                   remaining to fulfill capacity, and Amazon EMR can only provision an instance with a WeightedCapacity of 5 units, the instance is provisioned,                   and the target capacity is exceeded by 3 units.                   NOTE: If not specified or set to 0, only On-Demand instances are provisioned for the instance fleet. At least one of TargetSpotCapacity and                   TargetOnDemandCapacity should be greater than 0. For a master instance fleet, only one of TargetSpotCapacity and TargetOnDemandCapacity can be                   specified, and its value must be 1.                  # noqa: E501

        :return: The target_spot_capacity of this EmrClusterDefinitionInstanceFleet.  # noqa: E501
        :rtype: int
        """
        return self._target_spot_capacity

    @target_spot_capacity.setter
    def target_spot_capacity(self, target_spot_capacity):
        """Sets the target_spot_capacity of this EmrClusterDefinitionInstanceFleet.

        The target capacity of Spot units for the instance fleet, which determines how many Spot instances to provision. When the                   instance fleet launches, Amazon EMR tries to provision Spot instances as specified by InstanceTypeConfig. Each instance configuration has a                   specified WeightedCapacity. When a Spot instance is provisioned, the WeightedCapacity units count toward the target capacity. Amazon EMR                   provisions instances until the target capacity is totally fulfilled, even if this results in an overage. For example, if there are 2 units                   remaining to fulfill capacity, and Amazon EMR can only provision an instance with a WeightedCapacity of 5 units, the instance is provisioned,                   and the target capacity is exceeded by 3 units.                   NOTE: If not specified or set to 0, only On-Demand instances are provisioned for the instance fleet. At least one of TargetSpotCapacity and                   TargetOnDemandCapacity should be greater than 0. For a master instance fleet, only one of TargetSpotCapacity and TargetOnDemandCapacity can be                   specified, and its value must be 1.                  # noqa: E501

        :param target_spot_capacity: The target_spot_capacity of this EmrClusterDefinitionInstanceFleet.  # noqa: E501
        :type: int
        """

        self._target_spot_capacity = target_spot_capacity

    @property
    def instance_type_configs(self):
        """Gets the instance_type_configs of this EmrClusterDefinitionInstanceFleet.  # noqa: E501

        The instance type configurations that define the EC2 instances in the instance fleet  # noqa: E501

        :return: The instance_type_configs of this EmrClusterDefinitionInstanceFleet.  # noqa: E501
        :rtype: list[EmrClusterDefinitionInstanceTypeConfig]
        """
        return self._instance_type_configs

    @instance_type_configs.setter
    def instance_type_configs(self, instance_type_configs):
        """Sets the instance_type_configs of this EmrClusterDefinitionInstanceFleet.

        The instance type configurations that define the EC2 instances in the instance fleet  # noqa: E501

        :param instance_type_configs: The instance_type_configs of this EmrClusterDefinitionInstanceFleet.  # noqa: E501
        :type: list[EmrClusterDefinitionInstanceTypeConfig]
        """

        self._instance_type_configs = instance_type_configs

    @property
    def launch_specifications(self):
        """Gets the launch_specifications of this EmrClusterDefinitionInstanceFleet.  # noqa: E501


        :return: The launch_specifications of this EmrClusterDefinitionInstanceFleet.  # noqa: E501
        :rtype: EmrClusterDefinitionLaunchSpecifications
        """
        return self._launch_specifications

    @launch_specifications.setter
    def launch_specifications(self, launch_specifications):
        """Sets the launch_specifications of this EmrClusterDefinitionInstanceFleet.


        :param launch_specifications: The launch_specifications of this EmrClusterDefinitionInstanceFleet.  # noqa: E501
        :type: EmrClusterDefinitionLaunchSpecifications
        """

        self._launch_specifications = launch_specifications

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmrClusterDefinitionInstanceFleet):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class Job(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'status': 'str',
        'namespace': 'str',
        'job_name': 'str',
        'start_time': 'datetime',
        'end_time': 'datetime',
        'current_workflow_step': 'WorkflowStep',
        'completed_workflow_steps': 'list[WorkflowStep]',
        'parameters': 'list[Parameter]',
        'activiti_job_xml': 'str',
        'workflow_errors': 'list[WorkflowError]',
        'delete_reason': 'str'
    }

    attribute_map = {
        'id': 'id',
        'status': 'status',
        'namespace': 'namespace',
        'job_name': 'jobName',
        'start_time': 'startTime',
        'end_time': 'endTime',
        'current_workflow_step': 'currentWorkflowStep',
        'completed_workflow_steps': 'completedWorkflowSteps',
        'parameters': 'parameters',
        'activiti_job_xml': 'activitiJobXml',
        'workflow_errors': 'workflowErrors',
        'delete_reason': 'deleteReason'
    }

    def __init__(self, id=None, status=None, namespace=None, job_name=None, start_time=None, end_time=None, current_workflow_step=None, completed_workflow_steps=None, parameters=None, activiti_job_xml=None, workflow_errors=None, delete_reason=None):  # noqa: E501
        """Job - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._status = None
        self._namespace = None
        self._job_name = None
        self._start_time = None
        self._end_time = None
        self._current_workflow_step = None
        self._completed_workflow_steps = None
        self._parameters = None
        self._activiti_job_xml = None
        self._workflow_errors = None
        self._delete_reason = None
        self.discriminator = None

        self.id = id
        if status is not None:
            self.status = status
        if namespace is not None:
            self.namespace = namespace
        if job_name is not None:
            self.job_name = job_name
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        if current_workflow_step is not None:
            self.current_workflow_step = current_workflow_step
        if completed_workflow_steps is not None:
            self.completed_workflow_steps = completed_workflow_steps
        if parameters is not None:
            self.parameters = parameters
        if activiti_job_xml is not None:
            self.activiti_job_xml = activiti_job_xml
        if workflow_errors is not None:
            self.workflow_errors = workflow_errors
        if delete_reason is not None:
            self.delete_reason = delete_reason

    @property
    def id(self):
        """Gets the id of this Job.  # noqa: E501

        The internal identifier that uniquely references a job  # noqa: E501

        :return: The id of this Job.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Job.

        The internal identifier that uniquely references a job  # noqa: E501

        :param id: The id of this Job.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def status(self):
        """Gets the status of this Job.  # noqa: E501

        The status of the job. One of the following values: RUNNING, SUSPENDED, COMPLETED  # noqa: E501

        :return: The status of this Job.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Job.

        The status of the job. One of the following values: RUNNING, SUSPENDED, COMPLETED  # noqa: E501

        :param status: The status of this Job.  # noqa: E501
        :type: str
        """
        allowed_values = ["RUNNING", "SUSPENDED", "COMPLETED"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def namespace(self):
        """Gets the namespace of this Job.  # noqa: E501

        The namespace of the job  # noqa: E501

        :return: The namespace of this Job.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this Job.

        The namespace of the job  # noqa: E501

        :param namespace: The namespace of this Job.  # noqa: E501
        :type: str
        """

        self._namespace = namespace

    @property
    def job_name(self):
        """Gets the job_name of this Job.  # noqa: E501

        The name of the job  # noqa: E501

        :return: The job_name of this Job.  # noqa: E501
        :rtype: str
        """
        return self._job_name

    @job_name.setter
    def job_name(self, job_name):
        """Sets the job_name of this Job.

        The name of the job  # noqa: E501

        :param job_name: The job_name of this Job.  # noqa: E501
        :type: str
        """

        self._job_name = job_name

    @property
    def start_time(self):
        """Gets the start_time of this Job.  # noqa: E501

        The start time of the job  # noqa: E501

        :return: The start_time of this Job.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this Job.

        The start time of the job  # noqa: E501

        :param start_time: The start_time of this Job.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this Job.  # noqa: E501

        The end time of the job. It is not returned for a job in RUNNING state  # noqa: E501

        :return: The end_time of this Job.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this Job.

        The end time of the job. It is not returned for a job in RUNNING state  # noqa: E501

        :param end_time: The end_time of this Job.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    @property
    def current_workflow_step(self):
        """Gets the current_workflow_step of this Job.  # noqa: E501


        :return: The current_workflow_step of this Job.  # noqa: E501
        :rtype: WorkflowStep
        """
        return self._current_workflow_step

    @current_workflow_step.setter
    def current_workflow_step(self, current_workflow_step):
        """Sets the current_workflow_step of this Job.


        :param current_workflow_step: The current_workflow_step of this Job.  # noqa: E501
        :type: WorkflowStep
        """

        self._current_workflow_step = current_workflow_step

    @property
    def completed_workflow_steps(self):
        """Gets the completed_workflow_steps of this Job.  # noqa: E501

        The steps that have been completed. For a job in RUNNING state, steps up to the last Async task will be returned. For a job in                   COMPLETED state, all executed steps will be returned                  # noqa: E501

        :return: The completed_workflow_steps of this Job.  # noqa: E501
        :rtype: list[WorkflowStep]
        """
        return self._completed_workflow_steps

    @completed_workflow_steps.setter
    def completed_workflow_steps(self, completed_workflow_steps):
        """Sets the completed_workflow_steps of this Job.

        The steps that have been completed. For a job in RUNNING state, steps up to the last Async task will be returned. For a job in                   COMPLETED state, all executed steps will be returned                  # noqa: E501

        :param completed_workflow_steps: The completed_workflow_steps of this Job.  # noqa: E501
        :type: list[WorkflowStep]
        """

        self._completed_workflow_steps = completed_workflow_steps

    @property
    def parameters(self):
        """Gets the parameters of this Job.  # noqa: E501

        Current workflow variables and values  # noqa: E501

        :return: The parameters of this Job.  # noqa: E501
        :rtype: list[Parameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this Job.

        Current workflow variables and values  # noqa: E501

        :param parameters: The parameters of this Job.  # noqa: E501
        :type: list[Parameter]
        """

        self._parameters = parameters

    @property
    def activiti_job_xml(self):
        """Gets the activiti_job_xml of this Job.  # noqa: E501

        Activiti workflow XML related to the job  # noqa: E501

        :return: The activiti_job_xml of this Job.  # noqa: E501
        :rtype: str
        """
        return self._activiti_job_xml

    @activiti_job_xml.setter
    def activiti_job_xml(self, activiti_job_xml):
        """Sets the activiti_job_xml of this Job.

        Activiti workflow XML related to the job  # noqa: E501

        :param activiti_job_xml: The activiti_job_xml of this Job.  # noqa: E501
        :type: str
        """

        self._activiti_job_xml = activiti_job_xml

    @property
    def workflow_errors(self):
        """Gets the workflow_errors of this Job.  # noqa: E501

        The workflow errors  # noqa: E501

        :return: The workflow_errors of this Job.  # noqa: E501
        :rtype: list[WorkflowError]
        """
        return self._workflow_errors

    @workflow_errors.setter
    def workflow_errors(self, workflow_errors):
        """Sets the workflow_errors of this Job.

        The workflow errors  # noqa: E501

        :param workflow_errors: The workflow_errors of this Job.  # noqa: E501
        :type: list[WorkflowError]
        """

        self._workflow_errors = workflow_errors

    @property
    def delete_reason(self):
        """Gets the delete_reason of this Job.  # noqa: E501

        A reason this job has been deleted. It is returned if the job has been deleted  # noqa: E501

        :return: The delete_reason of this Job.  # noqa: E501
        :rtype: str
        """
        return self._delete_reason

    @delete_reason.setter
    def delete_reason(self, delete_reason):
        """Sets the delete_reason of this Job.

        A reason this job has been deleted. It is returned if the job has been deleted  # noqa: E501

        :param delete_reason: The delete_reason of this Job.  # noqa: E501
        :type: str
        """

        self._delete_reason = delete_reason

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Job):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.job_api import JobApi  # noqa: E501
from herdsdk.rest import ApiException


class TestJobApi(unittest.TestCase):
    """JobApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.job_api.JobApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_job_create_job(self):
        """Test case for job_create_job

        createJob  # noqa: E501
        """
        pass

    def test_job_delete_job(self):
        """Test case for job_delete_job

        deleteJob  # noqa: E501
        """
        pass

    def test_job_get_job(self):
        """Test case for job_get_job

        getJob  # noqa: E501
        """
        pass

    def test_job_get_jobs(self):
        """Test case for job_get_jobs

        getJobs  # noqa: E501
        """
        pass

    def test_job_signal_job(self):
        """Test case for job_signal_job

        signalJob  # noqa: E501
        """
        pass

    def test_job_update_job(self):
        """Test case for job_update_job

        updateJob  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectDataDdlRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'namespace': 'str',
        'business_object_definition_name': 'str',
        'business_object_format_usage': 'str',
        'business_object_format_file_type': 'str',
        'business_object_format_version': 'int',
        'partition_value_filters': 'list[PartitionValueFilter]',
        'partition_value_filter': 'PartitionValueFilter',
        'business_object_data_version': 'int',
        'business_object_data_status': 'str',
        'storage_names': 'list[str]',
        'storage_name': 'str',
        'output_format': 'str',
        'table_name': 'str',
        'custom_ddl_name': 'str',
        'include_drop_table_statement': 'bool',
        'include_if_not_exists_option': 'bool',
        'include_drop_partitions': 'bool',
        'include_single_location': 'bool',
        'allow_missing_data': 'bool',
        'include_all_registered_sub_partitions': 'bool',
        'suppress_scan_for_unregistered_sub_partitions': 'bool',
        'combine_multiple_partitions_in_single_alter_table': 'bool',
        'combined_alter_table_max_partitions': 'int',
        'as_of_time': 'datetime',
        'suppress_quotes_in_numeric_type_partition_values': 'bool'
    }

    attribute_map = {
        'namespace': 'namespace',
        'business_object_definition_name': 'businessObjectDefinitionName',
        'business_object_format_usage': 'businessObjectFormatUsage',
        'business_object_format_file_type': 'businessObjectFormatFileType',
        'business_object_format_version': 'businessObjectFormatVersion',
        'partition_value_filters': 'partitionValueFilters',
        'partition_value_filter': 'partitionValueFilter',
        'business_object_data_version': 'businessObjectDataVersion',
        'business_object_data_status': 'businessObjectDataStatus',
        'storage_names': 'storageNames',
        'storage_name': 'storageName',
        'output_format': 'outputFormat',
        'table_name': 'tableName',
        'custom_ddl_name': 'customDdlName',
        'include_drop_table_statement': 'includeDropTableStatement',
        'include_if_not_exists_option': 'includeIfNotExistsOption',
        'include_drop_partitions': 'includeDropPartitions',
        'include_single_location': 'includeSingleLocation',
        'allow_missing_data': 'allowMissingData',
        'include_all_registered_sub_partitions': 'includeAllRegisteredSubPartitions',
        'suppress_scan_for_unregistered_sub_partitions': 'suppressScanForUnregisteredSubPartitions',
        'combine_multiple_partitions_in_single_alter_table': 'combineMultiplePartitionsInSingleAlterTable',
        'combined_alter_table_max_partitions': 'combinedAlterTableMaxPartitions',
        'as_of_time': 'asOfTime',
        'suppress_quotes_in_numeric_type_partition_values': 'suppressQuotesInNumericTypePartitionValues'
    }

    def __init__(self, namespace=None, business_object_definition_name=None, business_object_format_usage=None, business_object_format_file_type=None, business_object_format_version=None, partition_value_filters=None, partition_value_filter=None, business_object_data_version=None, business_object_data_status=None, storage_names=None, storage_name=None, output_format=None, table_name=None, custom_ddl_name=None, include_drop_table_statement=None, include_if_not_exists_option=None, include_drop_partitions=None, include_single_location=None, allow_missing_data=None, include_all_registered_sub_partitions=None, suppress_scan_for_unregistered_sub_partitions=None, combine_multiple_partitions_in_single_alter_table=None, combined_alter_table_max_partitions=None, as_of_time=None, suppress_quotes_in_numeric_type_partition_values=None):  # noqa: E501
        """BusinessObjectDataDdlRequest - a model defined in OpenAPI"""  # noqa: E501

        self._namespace = None
        self._business_object_definition_name = None
        self._business_object_format_usage = None
        self._business_object_format_file_type = None
        self._business_object_format_version = None
        self._partition_value_filters = None
        self._partition_value_filter = None
        self._business_object_data_version = None
        self._business_object_data_status = None
        self._storage_names = None
        self._storage_name = None
        self._output_format = None
        self._table_name = None
        self._custom_ddl_name = None
        self._include_drop_table_statement = None
        self._include_if_not_exists_option = None
        self._include_drop_partitions = None
        self._include_single_location = None
        self._allow_missing_data = None
        self._include_all_registered_sub_partitions = None
        self._suppress_scan_for_unregistered_sub_partitions = None
        self._combine_multiple_partitions_in_single_alter_table = None
        self._combined_alter_table_max_partitions = None
        self._as_of_time = None
        self._suppress_quotes_in_numeric_type_partition_values = None
        self.discriminator = None

        self.namespace = namespace
        self.business_object_definition_name = business_object_definition_name
        self.business_object_format_usage = business_object_format_usage
        self.business_object_format_file_type = business_object_format_file_type
        if business_object_format_version is not None:
            self.business_object_format_version = business_object_format_version
        if partition_value_filters is not None:
            self.partition_value_filters = partition_value_filters
        if partition_value_filter is not None:
            self.partition_value_filter = partition_value_filter
        if business_object_data_version is not None:
            self.business_object_data_version = business_object_data_version
        if business_object_data_status is not None:
            self.business_object_data_status = business_object_data_status
        if storage_names is not None:
            self.storage_names = storage_names
        if storage_name is not None:
            self.storage_name = storage_name
        self.output_format = output_format
        self.table_name = table_name
        if custom_ddl_name is not None:
            self.custom_ddl_name = custom_ddl_name
        if include_drop_table_statement is not None:
            self.include_drop_table_statement = include_drop_table_statement
        if include_if_not_exists_option is not None:
            self.include_if_not_exists_option = include_if_not_exists_option
        if include_drop_partitions is not None:
            self.include_drop_partitions = include_drop_partitions
        if include_single_location is not None:
            self.include_single_location = include_single_location
        if allow_missing_data is not None:
            self.allow_missing_data = allow_missing_data
        if include_all_registered_sub_partitions is not None:
            self.include_all_registered_sub_partitions = include_all_registered_sub_partitions
        if suppress_scan_for_unregistered_sub_partitions is not None:
            self.suppress_scan_for_unregistered_sub_partitions = suppress_scan_for_unregistered_sub_partitions
        if combine_multiple_partitions_in_single_alter_table is not None:
            self.combine_multiple_partitions_in_single_alter_table = combine_multiple_partitions_in_single_alter_table
        if combined_alter_table_max_partitions is not None:
            self.combined_alter_table_max_partitions = combined_alter_table_max_partitions
        if as_of_time is not None:
            self.as_of_time = as_of_time
        if suppress_quotes_in_numeric_type_partition_values is not None:
            self.suppress_quotes_in_numeric_type_partition_values = suppress_quotes_in_numeric_type_partition_values

    @property
    def namespace(self):
        """Gets the namespace of this BusinessObjectDataDdlRequest.  # noqa: E501


        :return: The namespace of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this BusinessObjectDataDdlRequest.


        :param namespace: The namespace of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: str
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def business_object_definition_name(self):
        """Gets the business_object_definition_name of this BusinessObjectDataDdlRequest.  # noqa: E501


        :return: The business_object_definition_name of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_definition_name

    @business_object_definition_name.setter
    def business_object_definition_name(self, business_object_definition_name):
        """Sets the business_object_definition_name of this BusinessObjectDataDdlRequest.


        :param business_object_definition_name: The business_object_definition_name of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: str
        """
        if business_object_definition_name is None:
            raise ValueError("Invalid value for `business_object_definition_name`, must not be `None`")  # noqa: E501

        self._business_object_definition_name = business_object_definition_name

    @property
    def business_object_format_usage(self):
        """Gets the business_object_format_usage of this BusinessObjectDataDdlRequest.  # noqa: E501


        :return: The business_object_format_usage of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_usage

    @business_object_format_usage.setter
    def business_object_format_usage(self, business_object_format_usage):
        """Sets the business_object_format_usage of this BusinessObjectDataDdlRequest.


        :param business_object_format_usage: The business_object_format_usage of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: str
        """
        if business_object_format_usage is None:
            raise ValueError("Invalid value for `business_object_format_usage`, must not be `None`")  # noqa: E501

        self._business_object_format_usage = business_object_format_usage

    @property
    def business_object_format_file_type(self):
        """Gets the business_object_format_file_type of this BusinessObjectDataDdlRequest.  # noqa: E501


        :return: The business_object_format_file_type of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_file_type

    @business_object_format_file_type.setter
    def business_object_format_file_type(self, business_object_format_file_type):
        """Sets the business_object_format_file_type of this BusinessObjectDataDdlRequest.


        :param business_object_format_file_type: The business_object_format_file_type of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: str
        """
        if business_object_format_file_type is None:
            raise ValueError("Invalid value for `business_object_format_file_type`, must not be `None`")  # noqa: E501

        self._business_object_format_file_type = business_object_format_file_type

    @property
    def business_object_format_version(self):
        """Gets the business_object_format_version of this BusinessObjectDataDdlRequest.  # noqa: E501


        :return: The business_object_format_version of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: int
        """
        return self._business_object_format_version

    @business_object_format_version.setter
    def business_object_format_version(self, business_object_format_version):
        """Sets the business_object_format_version of this BusinessObjectDataDdlRequest.


        :param business_object_format_version: The business_object_format_version of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: int
        """

        self._business_object_format_version = business_object_format_version

    @property
    def partition_value_filters(self):
        """Gets the partition_value_filters of this BusinessObjectDataDdlRequest.  # noqa: E501


        :return: The partition_value_filters of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: list[PartitionValueFilter]
        """
        return self._partition_value_filters

    @partition_value_filters.setter
    def partition_value_filters(self, partition_value_filters):
        """Sets the partition_value_filters of this BusinessObjectDataDdlRequest.


        :param partition_value_filters: The partition_value_filters of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: list[PartitionValueFilter]
        """

        self._partition_value_filters = partition_value_filters

    @property
    def partition_value_filter(self):
        """Gets the partition_value_filter of this BusinessObjectDataDdlRequest.  # noqa: E501


        :return: The partition_value_filter of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: PartitionValueFilter
        """
        return self._partition_value_filter

    @partition_value_filter.setter
    def partition_value_filter(self, partition_value_filter):
        """Sets the partition_value_filter of this BusinessObjectDataDdlRequest.


        :param partition_value_filter: The partition_value_filter of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: PartitionValueFilter
        """

        self._partition_value_filter = partition_value_filter

    @property
    def business_object_data_version(self):
        """Gets the business_object_data_version of this BusinessObjectDataDdlRequest.  # noqa: E501


        :return: The business_object_data_version of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: int
        """
        return self._business_object_data_version

    @business_object_data_version.setter
    def business_object_data_version(self, business_object_data_version):
        """Sets the business_object_data_version of this BusinessObjectDataDdlRequest.


        :param business_object_data_version: The business_object_data_version of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: int
        """

        self._business_object_data_version = business_object_data_version

    @property
    def business_object_data_status(self):
        """Gets the business_object_data_status of this BusinessObjectDataDdlRequest.  # noqa: E501

        An optional Business Object Data Status value for available Business Object Data. Accepted values are VALID and all                   pre-registration status values, such as PROCESSING, UPLOADING, and PENDING_VALID. Default value is VALID. The request cannot                   contain both businessObjectDataVersion and businessObjectDataStatus values                  # noqa: E501

        :return: The business_object_data_status of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_data_status

    @business_object_data_status.setter
    def business_object_data_status(self, business_object_data_status):
        """Sets the business_object_data_status of this BusinessObjectDataDdlRequest.

        An optional Business Object Data Status value for available Business Object Data. Accepted values are VALID and all                   pre-registration status values, such as PROCESSING, UPLOADING, and PENDING_VALID. Default value is VALID. The request cannot                   contain both businessObjectDataVersion and businessObjectDataStatus values                  # noqa: E501

        :param business_object_data_status: The business_object_data_status of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: str
        """

        self._business_object_data_status = business_object_data_status

    @property
    def storage_names(self):
        """Gets the storage_names of this BusinessObjectDataDdlRequest.  # noqa: E501


        :return: The storage_names of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._storage_names

    @storage_names.setter
    def storage_names(self, storage_names):
        """Sets the storage_names of this BusinessObjectDataDdlRequest.


        :param storage_names: The storage_names of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: list[str]
        """

        self._storage_names = storage_names

    @property
    def storage_name(self):
        """Gets the storage_name of this BusinessObjectDataDdlRequest.  # noqa: E501


        :return: The storage_name of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: str
        """
        return self._storage_name

    @storage_name.setter
    def storage_name(self, storage_name):
        """Sets the storage_name of this BusinessObjectDataDdlRequest.


        :param storage_name: The storage_name of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: str
        """

        self._storage_name = storage_name

    @property
    def output_format(self):
        """Gets the output_format of this BusinessObjectDataDdlRequest.  # noqa: E501


        :return: The output_format of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: str
        """
        return self._output_format

    @output_format.setter
    def output_format(self, output_format):
        """Sets the output_format of this BusinessObjectDataDdlRequest.


        :param output_format: The output_format of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: str
        """
        if output_format is None:
            raise ValueError("Invalid value for `output_format`, must not be `None`")  # noqa: E501
        allowed_values = ["HIVE_13_DDL"]  # noqa: E501
        if output_format not in allowed_values:
            raise ValueError(
                "Invalid value for `output_format` ({0}), must be one of {1}"  # noqa: E501
                .format(output_format, allowed_values)
            )

        self._output_format = output_format

    @property
    def table_name(self):
        """Gets the table_name of this BusinessObjectDataDdlRequest.  # noqa: E501


        :return: The table_name of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: str
        """
        return self._table_name

    @table_name.setter
    def table_name(self, table_name):
        """Sets the table_name of this BusinessObjectDataDdlRequest.


        :param table_name: The table_name of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: str
        """
        if table_name is None:
            raise ValueError("Invalid value for `table_name`, must not be `None`")  # noqa: E501

        self._table_name = table_name

    @property
    def custom_ddl_name(self):
        """Gets the custom_ddl_name of this BusinessObjectDataDdlRequest.  # noqa: E501


        :return: The custom_ddl_name of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: str
        """
        return self._custom_ddl_name

    @custom_ddl_name.setter
    def custom_ddl_name(self, custom_ddl_name):
        """Sets the custom_ddl_name of this BusinessObjectDataDdlRequest.


        :param custom_ddl_name: The custom_ddl_name of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: str
        """

        self._custom_ddl_name = custom_ddl_name

    @property
    def include_drop_table_statement(self):
        """Gets the include_drop_table_statement of this BusinessObjectDataDdlRequest.  # noqa: E501


        :return: The include_drop_table_statement of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_drop_table_statement

    @include_drop_table_statement.setter
    def include_drop_table_statement(self, include_drop_table_statement):
        """Sets the include_drop_table_statement of this BusinessObjectDataDdlRequest.


        :param include_drop_table_statement: The include_drop_table_statement of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: bool
        """

        self._include_drop_table_statement = include_drop_table_statement

    @property
    def include_if_not_exists_option(self):
        """Gets the include_if_not_exists_option of this BusinessObjectDataDdlRequest.  # noqa: E501


        :return: The include_if_not_exists_option of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_if_not_exists_option

    @include_if_not_exists_option.setter
    def include_if_not_exists_option(self, include_if_not_exists_option):
        """Sets the include_if_not_exists_option of this BusinessObjectDataDdlRequest.


        :param include_if_not_exists_option: The include_if_not_exists_option of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: bool
        """

        self._include_if_not_exists_option = include_if_not_exists_option

    @property
    def include_drop_partitions(self):
        """Gets the include_drop_partitions of this BusinessObjectDataDdlRequest.  # noqa: E501


        :return: The include_drop_partitions of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_drop_partitions

    @include_drop_partitions.setter
    def include_drop_partitions(self, include_drop_partitions):
        """Sets the include_drop_partitions of this BusinessObjectDataDdlRequest.


        :param include_drop_partitions: The include_drop_partitions of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: bool
        """

        self._include_drop_partitions = include_drop_partitions

    @property
    def include_single_location(self):
        """Gets the include_single_location of this BusinessObjectDataDdlRequest.  # noqa: E501

        If true, for partitioned table, LOCATION statement will be added to the generated DDL with the value set to the first partition                   bucket name followed by the namespace prefix                  # noqa: E501

        :return: The include_single_location of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_single_location

    @include_single_location.setter
    def include_single_location(self, include_single_location):
        """Sets the include_single_location of this BusinessObjectDataDdlRequest.

        If true, for partitioned table, LOCATION statement will be added to the generated DDL with the value set to the first partition                   bucket name followed by the namespace prefix                  # noqa: E501

        :param include_single_location: The include_single_location of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: bool
        """

        self._include_single_location = include_single_location

    @property
    def allow_missing_data(self):
        """Gets the allow_missing_data of this BusinessObjectDataDdlRequest.  # noqa: E501


        :return: The allow_missing_data of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: bool
        """
        return self._allow_missing_data

    @allow_missing_data.setter
    def allow_missing_data(self, allow_missing_data):
        """Sets the allow_missing_data of this BusinessObjectDataDdlRequest.


        :param allow_missing_data: The allow_missing_data of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: bool
        """

        self._allow_missing_data = allow_missing_data

    @property
    def include_all_registered_sub_partitions(self):
        """Gets the include_all_registered_sub_partitions of this BusinessObjectDataDdlRequest.  # noqa: E501

        Specifies to perform an exhaustive search to return availability for ALL registered sub-partitions (registered as individual                   business object data instances) except for the ones with \"DELETED\" status. This parameter has no impact when business object data version is                   specified. Default value is false, which means that this endpoint ignores any \"not available\" registered sub-partitions when it finds at least                   one \"VALID\" registered sub-partition for a requested business object data partition value.                   If true, the call would fail with a \"Not Found\" (status code 404) error when it finds at least one \"not available\" (except for \"DELETED\")                   registered sub-partition for a requested business object data partition value                  # noqa: E501

        :return: The include_all_registered_sub_partitions of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_all_registered_sub_partitions

    @include_all_registered_sub_partitions.setter
    def include_all_registered_sub_partitions(self, include_all_registered_sub_partitions):
        """Sets the include_all_registered_sub_partitions of this BusinessObjectDataDdlRequest.

        Specifies to perform an exhaustive search to return availability for ALL registered sub-partitions (registered as individual                   business object data instances) except for the ones with \"DELETED\" status. This parameter has no impact when business object data version is                   specified. Default value is false, which means that this endpoint ignores any \"not available\" registered sub-partitions when it finds at least                   one \"VALID\" registered sub-partition for a requested business object data partition value.                   If true, the call would fail with a \"Not Found\" (status code 404) error when it finds at least one \"not available\" (except for \"DELETED\")                   registered sub-partition for a requested business object data partition value                  # noqa: E501

        :param include_all_registered_sub_partitions: The include_all_registered_sub_partitions of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: bool
        """

        self._include_all_registered_sub_partitions = include_all_registered_sub_partitions

    @property
    def suppress_scan_for_unregistered_sub_partitions(self):
        """Gets the suppress_scan_for_unregistered_sub_partitions of this BusinessObjectDataDdlRequest.  # noqa: E501

        Specifies to suppress scanning of registered storage files to discover sub-partitions and instead of that relies on business                   object data registration information to extract primary and sub-partition (if any) values required to identify Hive table partitions. Default                   value is false. If true, the call would fail with a \"Bad Request\" (status code 400) error when number of partitions in any of the discovered                   business object data instances does not match to the number of partition columns in the business object format being used to generate the DDL                   or retrieve business object partitions                  # noqa: E501

        :return: The suppress_scan_for_unregistered_sub_partitions of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: bool
        """
        return self._suppress_scan_for_unregistered_sub_partitions

    @suppress_scan_for_unregistered_sub_partitions.setter
    def suppress_scan_for_unregistered_sub_partitions(self, suppress_scan_for_unregistered_sub_partitions):
        """Sets the suppress_scan_for_unregistered_sub_partitions of this BusinessObjectDataDdlRequest.

        Specifies to suppress scanning of registered storage files to discover sub-partitions and instead of that relies on business                   object data registration information to extract primary and sub-partition (if any) values required to identify Hive table partitions. Default                   value is false. If true, the call would fail with a \"Bad Request\" (status code 400) error when number of partitions in any of the discovered                   business object data instances does not match to the number of partition columns in the business object format being used to generate the DDL                   or retrieve business object partitions                  # noqa: E501

        :param suppress_scan_for_unregistered_sub_partitions: The suppress_scan_for_unregistered_sub_partitions of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: bool
        """

        self._suppress_scan_for_unregistered_sub_partitions = suppress_scan_for_unregistered_sub_partitions

    @property
    def combine_multiple_partitions_in_single_alter_table(self):
        """Gets the combine_multiple_partitions_in_single_alter_table of this BusinessObjectDataDdlRequest.  # noqa: E501

        Specifies to add multiple partitions in a single ALTER TABLE statement. If includeDropPartitions is set to true, this flag also                   specifies to drop multiple partitions in a single ALTER TABLE statement                  # noqa: E501

        :return: The combine_multiple_partitions_in_single_alter_table of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: bool
        """
        return self._combine_multiple_partitions_in_single_alter_table

    @combine_multiple_partitions_in_single_alter_table.setter
    def combine_multiple_partitions_in_single_alter_table(self, combine_multiple_partitions_in_single_alter_table):
        """Sets the combine_multiple_partitions_in_single_alter_table of this BusinessObjectDataDdlRequest.

        Specifies to add multiple partitions in a single ALTER TABLE statement. If includeDropPartitions is set to true, this flag also                   specifies to drop multiple partitions in a single ALTER TABLE statement                  # noqa: E501

        :param combine_multiple_partitions_in_single_alter_table: The combine_multiple_partitions_in_single_alter_table of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: bool
        """

        self._combine_multiple_partitions_in_single_alter_table = combine_multiple_partitions_in_single_alter_table

    @property
    def combined_alter_table_max_partitions(self):
        """Gets the combined_alter_table_max_partitions of this BusinessObjectDataDdlRequest.  # noqa: E501

        Specifies the maximum number of add partition statements to include in a single ALTER TABLE statement. If includeDropPartitions                   is set to true, this parameter also applies to maximum number of drop partition statements in a single ALTER TABLE statement                  # noqa: E501

        :return: The combined_alter_table_max_partitions of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: int
        """
        return self._combined_alter_table_max_partitions

    @combined_alter_table_max_partitions.setter
    def combined_alter_table_max_partitions(self, combined_alter_table_max_partitions):
        """Sets the combined_alter_table_max_partitions of this BusinessObjectDataDdlRequest.

        Specifies the maximum number of add partition statements to include in a single ALTER TABLE statement. If includeDropPartitions                   is set to true, this parameter also applies to maximum number of drop partition statements in a single ALTER TABLE statement                  # noqa: E501

        :param combined_alter_table_max_partitions: The combined_alter_table_max_partitions of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: int
        """

        self._combined_alter_table_max_partitions = combined_alter_table_max_partitions

    @property
    def as_of_time(self):
        """Gets the as_of_time of this BusinessObjectDataDdlRequest.  # noqa: E501

        Specifies the date and time when the business object status was effective at that time, (ex 2015-12-30T11:08:40).                   The feature of 'asOfTime' looks for business object data SOLELY based on business object data status history,                   and it does NOT look for storage file status history for the business object selected                  # noqa: E501

        :return: The as_of_time of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._as_of_time

    @as_of_time.setter
    def as_of_time(self, as_of_time):
        """Sets the as_of_time of this BusinessObjectDataDdlRequest.

        Specifies the date and time when the business object status was effective at that time, (ex 2015-12-30T11:08:40).                   The feature of 'asOfTime' looks for business object data SOLELY based on business object data status history,                   and it does NOT look for storage file status history for the business object selected                  # noqa: E501

        :param as_of_time: The as_of_time of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: datetime
        """

        self._as_of_time = as_of_time

    @property
    def suppress_quotes_in_numeric_type_partition_values(self):
        """Gets the suppress_quotes_in_numeric_type_partition_values of this BusinessObjectDataDdlRequest.  # noqa: E501

        Specifies not to place single quotes around partition values where the columns are of numeric datatype  # noqa: E501

        :return: The suppress_quotes_in_numeric_type_partition_values of this BusinessObjectDataDdlRequest.  # noqa: E501
        :rtype: bool
        """
        return self._suppress_quotes_in_numeric_type_partition_values

    @suppress_quotes_in_numeric_type_partition_values.setter
    def suppress_quotes_in_numeric_type_partition_values(self, suppress_quotes_in_numeric_type_partition_values):
        """Sets the suppress_quotes_in_numeric_type_partition_values of this BusinessObjectDataDdlRequest.

        Specifies not to place single quotes around partition values where the columns are of numeric datatype  # noqa: E501

        :param suppress_quotes_in_numeric_type_partition_values: The suppress_quotes_in_numeric_type_partition_values of this BusinessObjectDataDdlRequest.  # noqa: E501
        :type: bool
        """

        self._suppress_quotes_in_numeric_type_partition_values = suppress_quotes_in_numeric_type_partition_values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectDataDdlRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.emr_api import EMRApi  # noqa: E501
from herdsdk.rest import ApiException


class TestEMRApi(unittest.TestCase):
    """EMRApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.emr_api.EMRApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_e_mr_add_hadoop_jar_step_to_emr_cluster(self):
        """Test case for e_mr_add_hadoop_jar_step_to_emr_cluster

        addHadoopJarStepToEmrCluster  # noqa: E501
        """
        pass

    def test_e_mr_add_hive_step_to_emr_cluster(self):
        """Test case for e_mr_add_hive_step_to_emr_cluster

        addHiveStepToEmrCluster  # noqa: E501
        """
        pass

    def test_e_mr_add_pig_step_to_emr_cluster(self):
        """Test case for e_mr_add_pig_step_to_emr_cluster

        addPigStepToEmrCluster  # noqa: E501
        """
        pass

    def test_e_mr_add_shell_step_to_emr_cluster(self):
        """Test case for e_mr_add_shell_step_to_emr_cluster

        addShellStepToEmrCluster  # noqa: E501
        """
        pass

    def test_e_mr_create_emr_cluster(self):
        """Test case for e_mr_create_emr_cluster

        createEmrCluster  # noqa: E501
        """
        pass

    def test_e_mr_get_emr_cluster(self):
        """Test case for e_mr_get_emr_cluster

        getEmrCluster  # noqa: E501
        """
        pass

    def test_e_mr_terminate_emr_cluster(self):
        """Test case for e_mr_terminate_emr_cluster

        terminateEmrCluster  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class EmrClusterInstanceTypeSpecification(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'instance_type': 'str',
        'weighted_capacity': 'int',
        'bid_price': 'str',
        'bid_price_as_percentage_of_on_demand_price': 'str',
        'ebs_optimized': 'bool',
        'ebs_block_devices': 'list[EmrClusterEbsBlockDevice]',
        'configurations': 'list[EmrClusterInstanceTypeConfiguration]'
    }

    attribute_map = {
        'instance_type': 'instanceType',
        'weighted_capacity': 'weightedCapacity',
        'bid_price': 'bidPrice',
        'bid_price_as_percentage_of_on_demand_price': 'bidPriceAsPercentageOfOnDemandPrice',
        'ebs_optimized': 'ebsOptimized',
        'ebs_block_devices': 'ebsBlockDevices',
        'configurations': 'configurations'
    }

    def __init__(self, instance_type=None, weighted_capacity=None, bid_price=None, bid_price_as_percentage_of_on_demand_price=None, ebs_optimized=None, ebs_block_devices=None, configurations=None):  # noqa: E501
        """EmrClusterInstanceTypeSpecification - a model defined in OpenAPI"""  # noqa: E501

        self._instance_type = None
        self._weighted_capacity = None
        self._bid_price = None
        self._bid_price_as_percentage_of_on_demand_price = None
        self._ebs_optimized = None
        self._ebs_block_devices = None
        self._configurations = None
        self.discriminator = None

        if instance_type is not None:
            self.instance_type = instance_type
        if weighted_capacity is not None:
            self.weighted_capacity = weighted_capacity
        if bid_price is not None:
            self.bid_price = bid_price
        if bid_price_as_percentage_of_on_demand_price is not None:
            self.bid_price_as_percentage_of_on_demand_price = bid_price_as_percentage_of_on_demand_price
        if ebs_optimized is not None:
            self.ebs_optimized = ebs_optimized
        if ebs_block_devices is not None:
            self.ebs_block_devices = ebs_block_devices
        if configurations is not None:
            self.configurations = configurations

    @property
    def instance_type(self):
        """Gets the instance_type of this EmrClusterInstanceTypeSpecification.  # noqa: E501

        An EC2 instance type, such as 'm3.xlarge'.                  # noqa: E501

        :return: The instance_type of this EmrClusterInstanceTypeSpecification.  # noqa: E501
        :rtype: str
        """
        return self._instance_type

    @instance_type.setter
    def instance_type(self, instance_type):
        """Sets the instance_type of this EmrClusterInstanceTypeSpecification.

        An EC2 instance type, such as 'm3.xlarge'.                  # noqa: E501

        :param instance_type: The instance_type of this EmrClusterInstanceTypeSpecification.  # noqa: E501
        :type: str
        """

        self._instance_type = instance_type

    @property
    def weighted_capacity(self):
        """Gets the weighted_capacity of this EmrClusterInstanceTypeSpecification.  # noqa: E501

        The number of units that a provisioned instance of this type provides toward fulfilling the target capacities defined in                   InstanceFleetConfig                  # noqa: E501

        :return: The weighted_capacity of this EmrClusterInstanceTypeSpecification.  # noqa: E501
        :rtype: int
        """
        return self._weighted_capacity

    @weighted_capacity.setter
    def weighted_capacity(self, weighted_capacity):
        """Sets the weighted_capacity of this EmrClusterInstanceTypeSpecification.

        The number of units that a provisioned instance of this type provides toward fulfilling the target capacities defined in                   InstanceFleetConfig                  # noqa: E501

        :param weighted_capacity: The weighted_capacity of this EmrClusterInstanceTypeSpecification.  # noqa: E501
        :type: int
        """

        self._weighted_capacity = weighted_capacity

    @property
    def bid_price(self):
        """Gets the bid_price of this EmrClusterInstanceTypeSpecification.  # noqa: E501

        The bid price for each EC2 Spot instance type as defined by InstanceType.                  # noqa: E501

        :return: The bid_price of this EmrClusterInstanceTypeSpecification.  # noqa: E501
        :rtype: str
        """
        return self._bid_price

    @bid_price.setter
    def bid_price(self, bid_price):
        """Sets the bid_price of this EmrClusterInstanceTypeSpecification.

        The bid price for each EC2 Spot instance type as defined by InstanceType.                  # noqa: E501

        :param bid_price: The bid_price of this EmrClusterInstanceTypeSpecification.  # noqa: E501
        :type: str
        """

        self._bid_price = bid_price

    @property
    def bid_price_as_percentage_of_on_demand_price(self):
        """Gets the bid_price_as_percentage_of_on_demand_price of this EmrClusterInstanceTypeSpecification.  # noqa: E501

        The bid price, as a percentage of On-Demand price, for each EC2 Spot instance as defined by InstanceType                  # noqa: E501

        :return: The bid_price_as_percentage_of_on_demand_price of this EmrClusterInstanceTypeSpecification.  # noqa: E501
        :rtype: str
        """
        return self._bid_price_as_percentage_of_on_demand_price

    @bid_price_as_percentage_of_on_demand_price.setter
    def bid_price_as_percentage_of_on_demand_price(self, bid_price_as_percentage_of_on_demand_price):
        """Sets the bid_price_as_percentage_of_on_demand_price of this EmrClusterInstanceTypeSpecification.

        The bid price, as a percentage of On-Demand price, for each EC2 Spot instance as defined by InstanceType                  # noqa: E501

        :param bid_price_as_percentage_of_on_demand_price: The bid_price_as_percentage_of_on_demand_price of this EmrClusterInstanceTypeSpecification.  # noqa: E501
        :type: str
        """

        self._bid_price_as_percentage_of_on_demand_price = bid_price_as_percentage_of_on_demand_price

    @property
    def ebs_optimized(self):
        """Gets the ebs_optimized of this EmrClusterInstanceTypeSpecification.  # noqa: E501

        Evaluates to TRUE when the specified InstanceType is EBS-optimized                  # noqa: E501

        :return: The ebs_optimized of this EmrClusterInstanceTypeSpecification.  # noqa: E501
        :rtype: bool
        """
        return self._ebs_optimized

    @ebs_optimized.setter
    def ebs_optimized(self, ebs_optimized):
        """Sets the ebs_optimized of this EmrClusterInstanceTypeSpecification.

        Evaluates to TRUE when the specified InstanceType is EBS-optimized                  # noqa: E501

        :param ebs_optimized: The ebs_optimized of this EmrClusterInstanceTypeSpecification.  # noqa: E501
        :type: bool
        """

        self._ebs_optimized = ebs_optimized

    @property
    def ebs_block_devices(self):
        """Gets the ebs_block_devices of this EmrClusterInstanceTypeSpecification.  # noqa: E501

        The configuration of Amazon Elastic Block Storage (EBS) attached to each instance as defined by InstanceType                  # noqa: E501

        :return: The ebs_block_devices of this EmrClusterInstanceTypeSpecification.  # noqa: E501
        :rtype: list[EmrClusterEbsBlockDevice]
        """
        return self._ebs_block_devices

    @ebs_block_devices.setter
    def ebs_block_devices(self, ebs_block_devices):
        """Sets the ebs_block_devices of this EmrClusterInstanceTypeSpecification.

        The configuration of Amazon Elastic Block Storage (EBS) attached to each instance as defined by InstanceType                  # noqa: E501

        :param ebs_block_devices: The ebs_block_devices of this EmrClusterInstanceTypeSpecification.  # noqa: E501
        :type: list[EmrClusterEbsBlockDevice]
        """

        self._ebs_block_devices = ebs_block_devices

    @property
    def configurations(self):
        """Gets the configurations of this EmrClusterInstanceTypeSpecification.  # noqa: E501

        A configuration classification that applies when provisioning cluster instances, which can include configurations for                   applications and software bundled with Amazon EMR                  # noqa: E501

        :return: The configurations of this EmrClusterInstanceTypeSpecification.  # noqa: E501
        :rtype: list[EmrClusterInstanceTypeConfiguration]
        """
        return self._configurations

    @configurations.setter
    def configurations(self, configurations):
        """Sets the configurations of this EmrClusterInstanceTypeSpecification.

        A configuration classification that applies when provisioning cluster instances, which can include configurations for                   applications and software bundled with Amazon EMR                  # noqa: E501

        :param configurations: The configurations of this EmrClusterInstanceTypeSpecification.  # noqa: E501
        :type: list[EmrClusterInstanceTypeConfiguration]
        """

        self._configurations = configurations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmrClusterInstanceTypeSpecification):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from herdsdk.api_client import ApiClient


class TagTypeApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def tag_type_create_tag_type(self, tag_type_create_request, **kwargs):  # noqa: E501
        """createTagType  # noqa: E501

        Creates a new tag type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_type_create_tag_type(tag_type_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TagTypeCreateRequest tag_type_create_request: the information needed to create the tag type (required)
        :return: TagType
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tag_type_create_tag_type_with_http_info(tag_type_create_request, **kwargs)  # noqa: E501
        else:
            (data) = self.tag_type_create_tag_type_with_http_info(tag_type_create_request, **kwargs)  # noqa: E501
            return data

    def tag_type_create_tag_type_with_http_info(self, tag_type_create_request, **kwargs):  # noqa: E501
        """createTagType  # noqa: E501

        Creates a new tag type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_type_create_tag_type_with_http_info(tag_type_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TagTypeCreateRequest tag_type_create_request: the information needed to create the tag type (required)
        :return: TagType
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['tag_type_create_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tag_type_create_tag_type" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'tag_type_create_request' is set
        if ('tag_type_create_request' not in local_var_params or
                local_var_params['tag_type_create_request'] is None):
            raise ValueError("Missing the required parameter `tag_type_create_request` when calling `tag_type_create_tag_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'tag_type_create_request' in local_var_params:
            body_params = local_var_params['tag_type_create_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/tagTypes', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TagType',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tag_type_delete_tag_type(self, tag_type_code, **kwargs):  # noqa: E501
        """deleteTagType  # noqa: E501

        Deletes an existing tag type by tag type code.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_type_delete_tag_type(tag_type_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tag_type_code: the tag type code (required)
        :return: TagType
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tag_type_delete_tag_type_with_http_info(tag_type_code, **kwargs)  # noqa: E501
        else:
            (data) = self.tag_type_delete_tag_type_with_http_info(tag_type_code, **kwargs)  # noqa: E501
            return data

    def tag_type_delete_tag_type_with_http_info(self, tag_type_code, **kwargs):  # noqa: E501
        """deleteTagType  # noqa: E501

        Deletes an existing tag type by tag type code.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_type_delete_tag_type_with_http_info(tag_type_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tag_type_code: the tag type code (required)
        :return: TagType
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['tag_type_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tag_type_delete_tag_type" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'tag_type_code' is set
        if ('tag_type_code' not in local_var_params or
                local_var_params['tag_type_code'] is None):
            raise ValueError("Missing the required parameter `tag_type_code` when calling `tag_type_delete_tag_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'tag_type_code' in local_var_params:
            path_params['tagTypeCode'] = local_var_params['tag_type_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/tagTypes/{tagTypeCode}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TagType',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tag_type_get_tag_type(self, tag_type_code, **kwargs):  # noqa: E501
        """getTagType  # noqa: E501

        Gets an existing tag type by tag type code.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_type_get_tag_type(tag_type_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tag_type_code: the tag type code (required)
        :return: TagType
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tag_type_get_tag_type_with_http_info(tag_type_code, **kwargs)  # noqa: E501
        else:
            (data) = self.tag_type_get_tag_type_with_http_info(tag_type_code, **kwargs)  # noqa: E501
            return data

    def tag_type_get_tag_type_with_http_info(self, tag_type_code, **kwargs):  # noqa: E501
        """getTagType  # noqa: E501

        Gets an existing tag type by tag type code.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_type_get_tag_type_with_http_info(tag_type_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tag_type_code: the tag type code (required)
        :return: TagType
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['tag_type_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tag_type_get_tag_type" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'tag_type_code' is set
        if ('tag_type_code' not in local_var_params or
                local_var_params['tag_type_code'] is None):
            raise ValueError("Missing the required parameter `tag_type_code` when calling `tag_type_get_tag_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'tag_type_code' in local_var_params:
            path_params['tagTypeCode'] = local_var_params['tag_type_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/tagTypes/{tagTypeCode}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TagType',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tag_type_get_tag_types(self, **kwargs):  # noqa: E501
        """getTagTypes  # noqa: E501

        Gets a list of tag type keys for all tag types defined in the system.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_type_get_tag_types(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: TagTypeKeys
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tag_type_get_tag_types_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.tag_type_get_tag_types_with_http_info(**kwargs)  # noqa: E501
            return data

    def tag_type_get_tag_types_with_http_info(self, **kwargs):  # noqa: E501
        """getTagTypes  # noqa: E501

        Gets a list of tag type keys for all tag types defined in the system.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_type_get_tag_types_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: TagTypeKeys
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tag_type_get_tag_types" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/tagTypes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TagTypeKeys',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tag_type_search_tag_types(self, tag_type_search_request, **kwargs):  # noqa: E501
        """searchTagTypes  # noqa: E501

        Retrieves all tag types existing in the system. For each tag type entity, the endpoint returns tag type key by default along with any other top-level elements as specified by the \"fields\" query string parameter. The list of tag types returned by the endpoint is sorted alphabetically by tag type's order value ascending.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_type_search_tag_types(tag_type_search_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TagTypeSearchRequest tag_type_search_request: the tag type search request. The request does not take any search keys or filters (required)
        :param str fields: the field options for the tag type search response. The valid field options are: displayName, tagTypeOrder and description
        :return: TagTypeSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tag_type_search_tag_types_with_http_info(tag_type_search_request, **kwargs)  # noqa: E501
        else:
            (data) = self.tag_type_search_tag_types_with_http_info(tag_type_search_request, **kwargs)  # noqa: E501
            return data

    def tag_type_search_tag_types_with_http_info(self, tag_type_search_request, **kwargs):  # noqa: E501
        """searchTagTypes  # noqa: E501

        Retrieves all tag types existing in the system. For each tag type entity, the endpoint returns tag type key by default along with any other top-level elements as specified by the \"fields\" query string parameter. The list of tag types returned by the endpoint is sorted alphabetically by tag type's order value ascending.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_type_search_tag_types_with_http_info(tag_type_search_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TagTypeSearchRequest tag_type_search_request: the tag type search request. The request does not take any search keys or filters (required)
        :param str fields: the field options for the tag type search response. The valid field options are: displayName, tagTypeOrder and description
        :return: TagTypeSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['tag_type_search_request', 'fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tag_type_search_tag_types" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'tag_type_search_request' is set
        if ('tag_type_search_request' not in local_var_params or
                local_var_params['tag_type_search_request'] is None):
            raise ValueError("Missing the required parameter `tag_type_search_request` when calling `tag_type_search_tag_types`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'fields' in local_var_params:
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'tag_type_search_request' in local_var_params:
            body_params = local_var_params['tag_type_search_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/tagTypes/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TagTypeSearchResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tag_type_update_tag_type(self, tag_type_code, tag_type_update_request, **kwargs):  # noqa: E501
        """updateTagType  # noqa: E501

        Updates an existing tag type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_type_update_tag_type(tag_type_code, tag_type_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tag_type_code: the tag type code (required)
        :param TagTypeUpdateRequest tag_type_update_request: the information needed to update the tag type (required)
        :return: TagType
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tag_type_update_tag_type_with_http_info(tag_type_code, tag_type_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.tag_type_update_tag_type_with_http_info(tag_type_code, tag_type_update_request, **kwargs)  # noqa: E501
            return data

    def tag_type_update_tag_type_with_http_info(self, tag_type_code, tag_type_update_request, **kwargs):  # noqa: E501
        """updateTagType  # noqa: E501

        Updates an existing tag type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_type_update_tag_type_with_http_info(tag_type_code, tag_type_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tag_type_code: the tag type code (required)
        :param TagTypeUpdateRequest tag_type_update_request: the information needed to update the tag type (required)
        :return: TagType
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['tag_type_code', 'tag_type_update_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tag_type_update_tag_type" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'tag_type_code' is set
        if ('tag_type_code' not in local_var_params or
                local_var_params['tag_type_code'] is None):
            raise ValueError("Missing the required parameter `tag_type_code` when calling `tag_type_update_tag_type`")  # noqa: E501
        # verify the required parameter 'tag_type_update_request' is set
        if ('tag_type_update_request' not in local_var_params or
                local_var_params['tag_type_update_request'] is None):
            raise ValueError("Missing the required parameter `tag_type_update_request` when calling `tag_type_update_tag_type`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'tag_type_code' in local_var_params:
            path_params['tagTypeCode'] = local_var_params['tag_type_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'tag_type_update_request' in local_var_params:
            body_params = local_var_params['tag_type_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/tagTypes/{tagTypeCode}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TagType',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.emr_cluster_definition_api import EMRClusterDefinitionApi  # noqa: E501
from herdsdk.rest import ApiException


class TestEMRClusterDefinitionApi(unittest.TestCase):
    """EMRClusterDefinitionApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.emr_cluster_definition_api.EMRClusterDefinitionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_e_mr_cluster_definition_create_emr_cluster_definition(self):
        """Test case for e_mr_cluster_definition_create_emr_cluster_definition

        createEmrClusterDefinition  # noqa: E501
        """
        pass

    def test_e_mr_cluster_definition_delete_emr_cluster_definition(self):
        """Test case for e_mr_cluster_definition_delete_emr_cluster_definition

        deleteEmrClusterDefinition  # noqa: E501
        """
        pass

    def test_e_mr_cluster_definition_get_emr_cluster_definition(self):
        """Test case for e_mr_cluster_definition_get_emr_cluster_definition

        getEmrClusterDefinition  # noqa: E501
        """
        pass

    def test_e_mr_cluster_definition_get_emr_cluster_definitions(self):
        """Test case for e_mr_cluster_definition_get_emr_cluster_definitions

        getEmrClusterDefinitions  # noqa: E501
        """
        pass

    def test_e_mr_cluster_definition_update_emr_cluster_definition(self):
        """Test case for e_mr_cluster_definition_update_emr_cluster_definition

        updateEmrClusterDefinition  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
